/*
 * Dev_Conf.h
 *
 *  Created on: 2025/02/26
 *      Author: egaono-electronics
 */

#ifndef DEV_CONF_H_
#define DEV_CONF_H_


//------------------------------------------
// 使用するCPUの選択
//------------------------------------------
// STM32F446RE
//------------------------------------------
#define def_USE_F446RE
//------------------------------------------

//------------------------------------------
// HALヘッダの定義
//------------------------------------------
#define def_Header_HAL  "stm32f4xx_hal.h"
//------------------------------------------

//--------------------------------------------------
// Peripheralヘッダの定義
//--------------------------------------------------
#define def_H_Periph_SPI    "H_STM32F4_SPI_1.h"
//--------------------------------------------------


//--------------------------------------------------------------
// CPU動作周波数の定義
//--------------------------------------------------------------
#define def_SystemClock    180000000  // 最高速
//--------------------------------------------------------------


//--------------------------------------------------------------
// ST LEDの定義
//--------------------------------------------------------------
//----------------------------------------------------------
// ST LEDのポートとピンの定義 : Base-F446RE基板のST1
//----------------------------------------------------------
#define  def_GPIOx_LED_ST       GPIOA
#define  def_GPIO_PIN_x_LED_ST  GPIO_PIN_7

#define def_GPIOx_CLK_ENABLE_LED_ST()  \
	                        __HAL_RCC_GPIOA_CLK_ENABLE()
//----------------------------------------------------------
//--------------------------------------------------------------


//--------------------------------------------------------------
// User Switchの定義
//--------------------------------------------------------------
//----------------------------------------------------------
// User Switchのポートとピンの定義 :
//                          Base-F446RE基板のSW1 : USER
//----------------------------------------------------------
#define def_GPIOx_USW       GPIOC
#define def_GPIO_PIN_x_USW  GPIO_PIN_13

#define def_GPIOx_CLK_ENABLE_USW()  \
	                        __HAL_RCC_GPIOC_CLK_ENABLE()
//----------------------------------------------------------


//--------------------------------------------------
// User Switch検出の定義
//--------------------------------------------------
#define def_H_Det_USW  "Detects_Pressed_USW.h"

#define def_M_Init_USW  Init_USW
#define def_M_Detect_USW  Detects_Pressed_USW

#define def_USW_OFF  GPIO_PIN_SET
#define def_USW_ON   GPIO_PIN_RESET
//--------------------------------------------------
//--------------------------------------------------------------



//----------------------------------------------------------
// LCD制御の定義
//----------------------------------------------------------


//----------------------------------------------
// RGBのbyte数の選択
//----------------------------------------------
//----------------------------------------------
#define def_LCD_Lengthwise  240
#define def_LCD_Widthwise   320
#define def_RGB_byte          2  // RGB 2byte


//----------------------------------------------------------
// LCD表示の向きを指定する。
//----------------------------------------------------------
//#define def_Dir_Disp_LCD  0  // def_LengthwiseL : 縦長 左
//#define def_Dir_Disp_LCD  1  // def_LengthwiseR : 縦長 右
#define def_Dir_Disp_LCD  2  // def_WidthwiseL : 横長 左
//#define def_Dir_Disp_LCD  3  // def_WidthwiseR : 横長 右
//----------------------------------------------------------


//----------------------------------------------------------
//--------------------------------------------------
// LCD : LEDピン : BackLight制御ピンの定義
//--------------------------------------------------
#define def_GPIOx_LCD_LED         GPIOA
#define def_GPIO_PIN_x_LCD_LED    GPIO_PIN_9


//--------------------------------------------------
// LCD : DCピンの定義
//--------------------------------------------------
#define def_GPIOx_LCD_DC         GPIOC
#define def_GPIO_PIN_x_LCD_DC    GPIO_PIN_2


//--------------------------------------------------
// LCD : RESETピンの定義
//--------------------------------------------------
#define def_GPIOx_LCD_Reset         GPIOA
#define def_GPIO_PIN_x_LCD_Reset    GPIO_PIN_10
//----------------------------------------------------------


//--------------------------------------------------
// LCD : CSピンの定義
//--------------------------------------------------
#define def_GPIOx_LCD_SPI_NSS         GPIOB
                            // def_GPIOx_SPI1_NSS
#define def_GPIO_PIN_x_LCD_SPI_NSS    GPIO_PIN_2
                            // def_GPIO_PIN_x_SPI1_NSS
//----------------------------------------------------------



//--------------------------------------------------------------
// 使用Fontの定義
//--------------------------------------------------------------
#define def_Font_ASCII_8x8_Array  FONT_uint8_aASCII_8x8_A
#define def_Font_ASCII_16x16_Array  FONT_uint8_aASCII_16x16_A
//--------------------------------------------------------------


//------------------------------------------------------
// 使用Fontのヘッダ定義
//------------------------------------------------------
#define def_H_Font_ASCII_8x8  "Font_ASCII_8x8_A.h"
#define def_H_Font_ASCII_16x16  "Font_ASCII_16x16_A.h"
//------------------------------------------------------



//----------------------------------------------------------
// SPI1 の定義
//----------------------------------------------------------

//------------------------------------------------------
// SPI1 Peripheral定義
//------------------------------------------------------
#define def_GPIOx_SPI1    GPIOB

#define def_GPIO_PIN_x_SPI1_SCK  GPIO_PIN_3
#define def_GPIO_PIN_x_SPI1_MISO   GPIO_PIN_4
#define def_GPIO_PIN_x_SPI1_MOSI   GPIO_PIN_5

#define def_GPIOx_SPI1_NSS       GPIOB
#define def_GPIO_PIN_x_SPI1_NSS  GPIO_PIN_2
//------------------------------------------------------


//------------------------------------------------------
// SPI1 Bufferサイズ : LCD 1Line分の送信データ数
//------------------------------------------------------
#define def_SPI1_TxBufferSize  \
                def_LCD_Widthwise * def_RGB_byte + 8
                        // LCDの1Line分の送信データ数 :
                    // 320dot x RGB + Command + Address
#define def_SPI1_RxBufferSize  def_SPI1_TxBufferSize
//------------------------------------------------------


//--------------------------------------------------------------
// SPI_BAUDRATEPRESCALER の定義
//--------------------------------------------------------------
// SPI_SCK が 10MHz になるように設定する。
//--------------------------------------------------------------
#define def_SPI_BAUDRATEPRESCALER_x  SPI_BAUDRATEPRESCALER_8
//--------------------------------------------------------------


#endif /* DEV_CONF_H_ */
